==> haskell-cipher-aes128-0.7.0.6-2-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-cipher-aes128.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 cipher-aes128
version:              0.7.0.6
visibility:           public
id:                   cipher-aes128-0.7.0.6-2metV9Clx0DGFpQp5tJICz
key:                  cipher-aes128-0.7.0.6-2metV9Clx0DGFpQp5tJICz
license:              BSD-3-Clause
copyright:            Thomas M. DuBuisson
maintainer:           thomas.dubuisson@gmail.com
author:               Thomas M. DuBuisson, Vincent Hanquez (See AUTHORS file)
homepage:             https://github.com/TomMD/cipher-aes128
synopsis:             AES and common modes using AES-NI when available.
description:
    Cipher-aes128 is an implementation of AES and common modes of operation.  It borrows Hanquez'\''s C AES code (see '\''cipher-aes'\'') but
    is unique due to including compile-time detection of
    NI compiler support, a slightly more functional interface
    for GCM operations, exposure of '\''Ptr'\'' based operations via the .Internal module, and build-in crypto-api support.
    Cipher-aes128 was originally developed as "'\''cipher-aes'\'' plus trampolines", which has since been adopted into cipher-aes.

category:             Cryptography
abi:                  fc550fe70ae573df1d6d236195070b8f
exposed:              True
exposed-modules:      Crypto.Cipher.AES128 Crypto.Cipher.AES128.Internal
import-dirs:          /usr/lib/ghc-9.0.1/site-local/cipher-aes128-0.7.0.6
library-dirs:         /usr/lib/ghc-9.0.1/site-local/cipher-aes128-0.7.0.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/cipher-aes128-0.7.0.6
hs-libraries:         HScipher-aes128-0.7.0.6-2metV9Clx0DGFpQp5tJICz
depends:
    base-4.15.0.0 bytestring-0.10.12.1
    cereal-0.5.8.2-61j1a5W2ABqDRz8HqQdVx7
    crypto-api-0.13.3-K4D4TqlwTtyDpSHz3hLF4b
    tagged-0.8.6.1-FL843C40q4d1DeuwYADr25

haddock-interfaces:
    /usr/share/doc/haskell-cipher-aes128/html/cipher-aes128.haddock

haddock-html:         /usr/share/doc/haskell-cipher-aes128/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-cipher-aes128-0.7.0.6-3-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-cipher-aes128.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 cipher-aes128
version:              0.7.0.6
visibility:           public
id:                   cipher-aes128-0.7.0.6-p0iF0LYidIA2ZFVG1pJyl
key:                  cipher-aes128-0.7.0.6-p0iF0LYidIA2ZFVG1pJyl
license:              BSD-3-Clause
copyright:            Thomas M. DuBuisson
maintainer:           thomas.dubuisson@gmail.com
author:               Thomas M. DuBuisson, Vincent Hanquez (See AUTHORS file)
homepage:             https://github.com/TomMD/cipher-aes128
synopsis:             AES and common modes using AES-NI when available.
description:
    Cipher-aes128 is an implementation of AES and common modes of operation.  It borrows Hanquez'\''s C AES code (see '\''cipher-aes'\'') but
    is unique due to including compile-time detection of
    NI compiler support, a slightly more functional interface
    for GCM operations, exposure of '\''Ptr'\'' based operations via the .Internal module, and build-in crypto-api support.
    Cipher-aes128 was originally developed as "'\''cipher-aes'\'' plus trampolines", which has since been adopted into cipher-aes.

category:             Cryptography
abi:                  1e7ca3887382fa2b5e3ef45e542390b4
exposed:              True
exposed-modules:      Crypto.Cipher.AES128 Crypto.Cipher.AES128.Internal
import-dirs:          /usr/lib/ghc-9.0.2/site-local/cipher-aes128-0.7.0.6
library-dirs:         /usr/lib/ghc-9.0.2/site-local/cipher-aes128-0.7.0.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.2/cipher-aes128-0.7.0.6
hs-libraries:         HScipher-aes128-0.7.0.6-p0iF0LYidIA2ZFVG1pJyl
depends:
    base-4.15.1.0 bytestring-0.10.12.1
    cereal-0.5.8.2-3mqeMFbPDR59NtNSFrV4h3
    crypto-api-0.13.3-BF7h8F67L4j3wIvu9guSXU
    tagged-0.8.6.1-79gYUUazit6EfoPS33FHdR

haddock-interfaces:
    /usr/share/doc/haskell-cipher-aes128/html/cipher-aes128.haddock

haddock-html:         /usr/share/doc/haskell-cipher-aes128/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
